@@ -81,40 +81,42 @@ class Dict_:
         """
         return self.__dict[key]
 
-
     def set(self, key: list, value: Any) -> None:
         """
-        Set à value from a key
-        :param key: str | int | float
+        Set a value in a nested dictionary using a list of keys.
+        :param key: list of keys (str | int | float) representing the path in the nested dictionary
         :param value: Any
         :return: None
         """
-
         d = self.__dict
 
         for i in key[:-1]:
+            if isinstance(d, Dict_):
+                # Vérifiez les types dans Dict_
 
-            if type(d) == Dict_:
+                # Si la clé n'existe pas, créer un nouveau Dict_
+                if i not in d.dict_:
+                    d.dict_[i] = Dict_({})
 
                 d._check_types(d.dict_)
-
+                # Descendre d'un niveau dans le dictionnaire
                 d = d.dict_[i]
 
             else:
-                d = d[i]
+                # Pour les dictionnaires standards
+                if i not in d:
+                    d[i] = {}
+                d = d[i]  # Descendre d'un niveau dans le dictionnaire
+            #print(d)
 
-        if type(d) == Dict_:
 
+        # Assigner la valeur à la clé finale
+        if isinstance(d, Dict_):
             d.dict_[key[-1]] = value
-
         else:
             d[key[-1]] = value
 
 
-        #self.__dict[key] = value
-
-
-
 
 class AttributDict(dict):
     def __getattr__(self, key):
